function sU=fCreateUs(nnodes,nf,nt)

% create sparse sU matrix of polarized connections
% in the jargon of graph theory, this is called the "incidence matrix of the directed graph"

% Inputs

% nnodes: the total number of nodes
% nf: vector of connections "from" (= negative poles)
% nt: vector of connections "to"   (= positive poles)
% nf must have the same number of elements as nt

% Output
% sU, sparse matrix of polarized connections
% ith column of sU contains -1 at row nf(i) and +1 at row nt(i)

% error checks

if length(nf)~=length(nt)
    disp('Lengths do not match.')
    return
end
nc=length(nf); % number of columns in U

if max(nf)>nnodes || max(nt)>nnodes || min(nf)<=0 || min(nt)<=0
    disp('Subscript out of range.')
    return
end

if sum(nf==nt)>0
    disp('Ill posed nf/nt: Self connection')
    return
end

% end check

i=[nf nt];
j=[1:nc 1:nc];
v=[-ones(1,nc) ones(1,nc)];
sU=sparse(i,j,v,nnodes,nc);

end



