function [m_inf,h_inf,j_inf,edtm,edth,edtj,tau_m,tau_h,tau_j] = mhjLR1_livshitz(V,dt)

% This function returns gating parameters of INa according to Luo and Rudy (1991) with modifications by Livshitz and Rudy (2009)

% Luo and Rudy
% A model of the ventricular cardiac action potential. Depolarization, repolarization, and their interaction.
% Circ Res 1991, 68:1501-1526

% Livshitz and Rudy
% Uniqueness and stability of action potential models during rest, pacing, and conduction using problem-solving environment
% Biophys J 2009, 97:1265-1276

% INPUT
%   V       voltage (mV), can be a vector
%   dt      time step (ms)

% OUTPUT
% for gates g = m, h or j, returns:
% g_inf: steady state value
% tau_g: time constant
% edtg = exp(-dt./tau_g) % useful for the Rush-Larsen method

lam=1./(1+exp((V+40)./1.5));

% gate m
am = 0.32.*(V+47.13)./(1-exp(-0.1.*(V+47.13)));              
bm = 0.08.*exp(-V./11);
m_inf=am./(am+bm);
tau_m=1./(am+bm);
edtm=exp(-dt./tau_m);

% gate h
ah = (1-lam).*(0) + (lam).*(0.135.*exp((80+V)./(-6.8)));
bh = (1-lam).*(1./(0.13.*(1+exp((V+10.66)./(-11.1))))) + (lam).*(3.56.*exp(0.079.*V)+310000.*exp(0.35.*V));           
h_inf=ah./(ah+bh);
tau_h=1./(ah+bh);
edth=exp(-dt./tau_h);

%gate j    
aj = (1-lam).*(0) + (lam).*((-1.2715*10^5.*exp(.2444.*V)-3.474.*10^(-5).*exp(-.04391.*V)).*(V+37.78)./(1+exp(0.311.*(V+79.23))));
bj = (1-lam).*(0.3.*exp(-2.535e-7.*V)./(1+exp(-.1.*(V+32)))) + (lam).*(0.1212.*exp(-.01052.*V)./(1+exp(-.1378.*(V+40.14))));
j_inf=aj./(aj+bj);
tau_j=1./(aj+bj);
edtj=exp(-dt./tau_j);
    
end

